summaryrefslogtreecommitdiff
path: root/tikzit/src/gtk/EdgeStyleSelector.h
diff options
context:
space:
mode:
Diffstat (limited to 'tikzit/src/gtk/EdgeStyleSelector.h')
-rw-r--r--tikzit/src/gtk/EdgeStyleSelector.h38
1 files changed, 15 insertions, 23 deletions
diff --git a/tikzit/src/gtk/EdgeStyleSelector.h b/tikzit/src/gtk/EdgeStyleSelector.h
index 935c9b7..904bd93 100644
--- a/tikzit/src/gtk/EdgeStyleSelector.h
+++ b/tikzit/src/gtk/EdgeStyleSelector.h
@@ -17,52 +17,44 @@
#import "TZFoundation.h"
#import <gtk/gtk.h>
-#import "StyleManager.h"
+
+@class EdgeStyle;
+@class EdgeStylesModel;
+@class StyleManager;
@interface EdgeStyleSelector: NSObject {
- GtkListStore *store;
+ EdgeStylesModel *model;
GtkTreeView *view;
- StyleManager *styleManager;
- BOOL linkedToActiveStyle;
- BOOL suppressSetActiveStyle;
}
/*!
@property widget
@brief The GTK widget
*/
-@property (readonly) GtkWidget *widget;
-
-/*!
- @property manager
- @brief The StyleManager to use. Default is [StyleManager manager]
- */
-@property (retain) StyleManager *styleManager;
+@property (readonly) GtkWidget *widget;
/*!
- @property linkedToActiveStyles
- @brief Whether the current selection should be the same as the
- style manager's active style
+ @property model
+ @brief The model to use.
*/
-@property (getter=isLinkedToActiveStyle) BOOL linkedToActiveStyle;
+@property (retain) EdgeStylesModel *model;
/*!
@property selectedStyle
- @brief The selected style. If linkedToActiveStyle is YES, this
- will be the same as [manager activeStyle].
+ @brief The selected style.
When this changes, a SelectedStyleChanged notification will be posted
*/
-@property (assign) EdgeStyle *selectedStyle;
+@property (assign) EdgeStyle *selectedStyle;
/*!
* Initialise with the default style manager
*/
-- (id) init;
+- (id) initWithStyleManager:(StyleManager*)m;
/*!
* Initialise with the given style manager
*/
-- (id) initWithStyleManager:(StyleManager*)m;
+- (id) initWithModel:(EdgeStylesModel*)model;
@end
@@ -17,52 +17,44 @@
/*!
- * Initialise with the default style manager
+ * Initialise with a new model for the given style manager
*/
@@ -17,52 +17,44 @@
/*!
- * Initialise with the given style manager
+ * Initialise with the given model
*/